<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

if ( !isset( $content_width ) ) {
	$content_width = 1200;
}

add_action('after_setup_theme', 'ranna_setup');
if ( !function_exists( 'ranna_setup' ) ) {
	function ranna_setup() {
		// Language
		load_theme_textdomain( 'ranna', RANNA_BASE_DIR . 'languages' );

		// Theme support
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
		add_theme_support( 'post-formats', array( 'aside', 'gallery', 'video', 'audio' ) );
		add_theme_support( 'woocommerce' );		
		// for gutenberg support
		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Sunset Orange', 'ranna' ),
				'slug' => 'sunset-orange',
				'color' => '#ff4a52',
			),
			array(
				'name' => esc_html__( 'Rose Bud', 'ranna' ),
				'slug' => 'rose-bud',
				'color' => '#faa8ac',
			),
			array(
				'name' => esc_html__( 'very light gray', 'ranna' ),
				'slug' => 'very-light-gray',
				'color' => '#eee',
			),
			array(
				'name' => esc_html__( 'very dark gray', 'ranna' ),
				'slug' => 'very-dark-gray',
				'color' => '#444',
			),
		) );
		add_theme_support( 'editor-font-sizes', array(
			array(
				'name' => esc_html__( 'Small', 'ranna' ),
				'size' => 12,
				'slug' => 'small'
			),
			array(
				'name' => esc_html__( 'Normal', 'ranna' ),
				'size' => 16,
				'slug' => 'normal'
			),
			array(
				'name' => esc_html__( 'Large', 'ranna' ),
				'size' => 36,
				'slug' => 'large'
			),
			array(
				'name' => esc_html__( 'Huge', 'ranna' ),
				'size' => 50,
				'slug' => 'huge'
			)
		) );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support('editor-styles');	
		
		// Image sizes
		add_image_size( 'ranna-size1', 1240, 578, true );   // Single Post
		add_image_size( 'ranna-size10', 1920, 600, true );   // Single recipe 2
		
		//PARVEZ
		add_image_size( 'ranna-size2', 210, 210, true );
		add_image_size( 'ranna-size3', 260, 286, true );
		add_image_size( 'ranna-size4', 374, 254, true );
		add_image_size( 'ranna-size5', 350, 277, true );
		add_image_size( 'ranna-size6', 530, 338, true );
		add_image_size( 'ranna-size7', 630, 517, true );	// Blog layout 2, Post Slider 5		
		add_image_size( 'ranna-size8', 850, 702, true );    // Post Slider 6, Post Box 4
		add_image_size( 'ranna-size9', 425, 710, true );    // Post Box 4
		add_image_size( 'ranna-size12', 370, 400, true );		
		add_image_size( 'ranna-size14', 630, 650, true );  	// Post Slider 6
		
		// Register menus
		register_nav_menus( array(
			'primary'  => esc_html__( 'Primary', 'ranna' ),
		) );		
	}
}

function ranna_theme_add_editor_styles() {
	add_editor_style( get_stylesheet_uri() );
}
add_action( 'admin_init', 'ranna_theme_add_editor_styles' );

// Initialize Widgets
add_action( 'widgets_init', 'ranna_widgets_register' );
if ( !function_exists( 'ranna_widgets_register' ) ) {
	function ranna_widgets_register() {
		
		$footer_widget_titles2 = array(
			'1' => esc_html__( 'Footer (Style 2) 1', 'ranna' ),
			'2' => esc_html__( 'Footer (Style 2) 2', 'ranna' ),
			'3' => esc_html__( 'Footer (Style 2) 3', 'ranna' ),
			'4' => esc_html__( 'Footer (Style 2) 4', 'ranna' ),
		);		
		$footer_widget_titles4 = array(
			'1' => esc_html__( 'Footer (Style 4) 1', 'ranna' ),
			'2' => esc_html__( 'Footer (Style 4) 2', 'ranna' ),
			'3' => esc_html__( 'Footer (Style 4) 3', 'ranna' ),
			'4' => esc_html__( 'Footer (Style 4) 4', 'ranna' ),
		);		
		$footer_widget_titles5 = array(
			'1' => esc_html__( 'Footer (style 5) 1', 'ranna' ),
			'2' => esc_html__( 'Footer (style 5) 2', 'ranna' ),
			'3' => esc_html__( 'Footer (style 5) 3', 'ranna' ),
			'4' => esc_html__( 'Footer (style 5) 4', 'ranna' ),
		);

		// Register Widget Areas ( Common )
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'ranna' ),
			'id'            => 'sidebar',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="rt-widget-title-holder"><h3 class="widgettitle">',
			'after_title'   => '<span class="titleinner"></span></h3></div>',
			) );
		
		register_sidebar( array(
			'name'          => esc_html__( 'Top Bar 4 - Left', 'ranna' ),
			'id'            => 'top4-left',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="hidden">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Top Bar 4 - Right', 'ranna' ),
			'id'            => 'top4-right',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="hidden">',
			'after_title'   => '</h3>',
		) );
		
		if ( class_exists( 'WooCommerce' ) ) {
			register_sidebar( array(
				'name'          => esc_html__( 'Shop Page', 'ranna' ),
				'id'            => 'ranna-shop',
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="hidden">',
				'after_title'   => '</h3>',
			) );
		}
		
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Style 1', 'ranna' ),
			'id'            => 'footer-style-1',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widgettitle '. RannaTheme::$footer_style .'">',
			'after_title'   => '</h3>',
		) );
		if ( !empty(RannaTheme::$options['footer_column_2']) ){
			$item_widget = RannaTheme::$options['footer_column_2'];
		} else {
			$item_widget = 3;
		}		
		for ( $i = 1; $i <= $item_widget; $i++ ) {
			register_sidebar( array(
				'name'          => $footer_widget_titles2[$i],
				'id'            => 'footer-style-2-'. $i,
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h3 class="widgettitle '. RannaTheme::$footer_style .'">',
				'after_title'   => '</h3>',
			) );
		}
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Style 3', 'ranna' ),
			'id'            => 'footer-style-3',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widgettitle '. RannaTheme::$footer_style .'">',
			'after_title'   => '</h3>',
		) );		
		register_sidebar( array(		
			'name'          => esc_html__( 'Footer Style 4', 'ranna' ),
			'id'            => 'footer-style-4',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widgettitle '. RannaTheme::$footer_style .'">',
			'after_title'   => '</h3>',
		) );		
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Style 5', 'ranna' ),
			'id'            => 'footer-style-5',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widgettitle '. RannaTheme::$footer_style .'">',
			'after_title'   => '</h3>',
		) );		
	}
}

// Footer Html
add_action( 'wp_footer', 'ranna_footer_html', 1 );
if( !function_exists( 'ranna_footer_html' ) ) {
	function ranna_footer_html(){
		// Back-to-top link
		if ( RannaTheme::$options['back_to_top'] ){
			echo '<a href="#" class="scrollToTop"><i class="fa fa-arrow-up"></i></a>';
		}
	}	
}

// advanced search functionality
function advanced_search_query($query) {

    if($query->is_search()) {
        // category terms search.
        if (isset($_GET['category']) && !empty($_GET['category'])) {
            $query->set('tax_query', array(array(
                'taxonomy' => 'product_cat',
                'field' => 'slug',
                'terms' => array($_GET['category']) )
            ));
        }    
    }
    return $query;
}
add_action('pre_get_posts', 'advanced_search_query', 1000);

/*social link to author profile page*/
add_action( 'show_user_profile', 'ranna_user_social_profile_fields' );
add_action( 'edit_user_profile', 'ranna_user_social_profile_fields' );

function ranna_user_social_profile_fields( $user ) { ?>

	<h3><?php esc_html_e( 'User Designation' , 'ranna' ); ?></h3>

	<table class="form-table">
		<tr>
			<th><label for="ranna_author_designation"><?php esc_html_e( 'Author Designation' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_designation" id="ranna_author_designation" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_designation', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Author Designation' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="ranna_author_company"><?php esc_html_e( 'Author Company' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_company" id="ranna_author_company" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_company', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Author Designation' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="ranna_author_phone"><?php esc_html_e( 'Author Phone' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_phone" id="ranna_author_phone" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_phone', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Author Phone number' , 'ranna' ); ?></span></td>
		</tr>
	</table>
		
	<h3><?php esc_html_e( 'Location' , 'ranna' ); ?></h3>

	<table class="form-table">
		<tr>
			<th><label for="ranna_address"><?php esc_html_e( 'Address' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_address" id="ranna_address" value="<?php echo esc_attr( get_the_author_meta( 'ranna_address', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your address.' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="city"><?php esc_html_e( 'City' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_city" id="ranna_author_city" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_city', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your city.' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="state"><?php esc_html_e( 'State' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_state" id="ranna_author_state" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_state', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your state' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="country"><?php esc_html_e( 'Country' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_country" id="ranna_author_country" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_country', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your country' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="zipcode"><?php esc_html_e( 'Zip Code' , 'ranna' ); ?></label></th>
			<td><input type="text" name="ranna_author_zipcode" id="ranna_author_zipcode" value="<?php echo esc_attr( get_the_author_meta( 'ranna_author_zipcode', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Zip code' , 'ranna' ); ?></span></td>
		</tr>
	</table>
	
	<h3><?php esc_html_e( 'Social profile information' , 'ranna' ); ?></h3>

	<table class="form-table">
		<tr>
			<th><label for="facebook"><?php esc_html_e( 'Facebook' , 'ranna' ); ?></label></th>
			<td><input type="text" name="facebook" id="facebook" value="<?php echo esc_attr( get_the_author_meta( 'ranna_facebook', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your facebook URL.' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="twitter"><?php esc_html_e( 'Twitter' , 'ranna' ); ?></label></th>
			<td><input type="text" name="twitter" id="twitter" value="<?php echo esc_attr( get_the_author_meta( 'ranna_twitter', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your Twitter username.' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="linkedin"><?php esc_html_e( 'LinkedIn' , 'ranna' ); ?></label></th>
			<td><input type="text" name="linkedin" id="linkedin" value="<?php echo esc_attr( get_the_author_meta( 'ranna_linkedin', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your LinkedIn Profile' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="gplus"><?php esc_html_e( 'Google+' , 'ranna' ); ?></label></th>
			<td><input type="text" name="gplus" id="gplus" value="<?php echo esc_attr( get_the_author_meta( 'ranna_gplus', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your google+ Profile' , 'ranna' ); ?></span></td>
		</tr>
		<tr>
			<th><label for="pinterest"><?php esc_html_e( 'Pinterest' , 'ranna' ); ?></label></th>
			<td><input type="text" name="pinterest" id="pinterest" value="<?php echo esc_attr( get_the_author_meta( 'ranna_pinterest', $user->ID ) ); ?>" class="regular-text" /><br /><span class="description"><?php esc_html_e( 'Please enter your pinterest' , 'ranna' ); ?></span></td>
		</tr>
	</table>
<?php }

add_action( 'personal_options_update', 'ranna_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'ranna_extra_profile_fields' );

function ranna_extra_profile_fields( $user_id ) {

	if ( !current_user_can( 'edit_user', $user_id ) )
		return false;

	update_user_meta( $user_id, 'ranna_facebook', $_POST['facebook'] );
	update_user_meta( $user_id, 'ranna_twitter', $_POST['twitter'] );
	update_user_meta( $user_id, 'ranna_linkedin', $_POST['linkedin'] );
	update_user_meta( $user_id, 'ranna_gplus', $_POST['gplus'] );
	update_user_meta( $user_id, 'ranna_pinterest', $_POST['pinterest'] );
	update_user_meta( $user_id, 'ranna_author_designation', $_POST['ranna_author_designation'] );
	update_user_meta( $user_id, 'ranna_author_phone', $_POST['ranna_author_phone'] );
	update_user_meta( $user_id, 'ranna_author_company', $_POST['ranna_author_company'] );
	update_user_meta( $user_id, 'ranna_address', $_POST['ranna_address'] );
	update_user_meta( $user_id, 'ranna_author_city', $_POST['ranna_author_city'] );
	update_user_meta( $user_id, 'ranna_author_state', $_POST['ranna_author_state'] );
	update_user_meta( $user_id, 'ranna_author_country', $_POST['ranna_author_country'] );
	update_user_meta( $user_id, 'ranna_author_zipcode', $_POST['ranna_author_zipcode'] );
	
}

/*find newest post/product with time*/
function ranna_is_new( $id ) {
	$now    = time();
	$published_date = get_post_time('U');
	$diff =  $now - $published_date;
	if ( $diff < 604800 ) { ?>
		<span class="new-post"><?php esc_html_e( 'New' , 'ranna' ); ?></span>
	<?php }
}

if( ! function_exists( 'ranna_post_img_src' )){
	function ranna_post_img_src( $size = 'ranna-size1' ){
		$post_id  = get_the_ID();
		$image_id = get_post_thumbnail_id( $post_id );
		$image    = wp_get_attachment_image_src( $image_id, $size );
		return $image[0];
	}
}

/*Post Time & time format*/
if( ! function_exists( 'ranna_get_time' )){

	function ranna_get_time( $return = false ){

		# Date is disabled globally ----------
		if( RannaTheme::$options['time_format'] == 'none' ){
			return false;
		}
		# Human Readable Post Dates ----------
		else if(  RannaTheme::$options['time_format'] == 'modern' ){

			$time_now  = current_time( 'timestamp' );
			$post_time = get_the_time( 'U' ) ;
			$since = sprintf( esc_html__( '%s ago' , 'ranna' ), human_time_diff( $post_time, $time_now ) );			
		}
		else{
			$since = get_the_date();
		}

		$post_time = '<span class="date meta-item"> <span>'.$since.'</span></span>';

		if( $return ){
			return $post_time;
		}

		echo wp_kses( $post_time , 'alltext_allow' );
	}
	
}

function widgets_scripts( $hook ) {
    if ( 'widgets.php' != $hook ) {
        return;
    }
    wp_enqueue_style( 'wp-color-picker' );
	
}
add_action( 'admin_enqueue_scripts', 'widgets_scripts' );

/*Module: Last Post update Date*/
function ranna_last_update() {

	$lastupdated_args = array(
		'orderby' => 'modified',
		'posts_per_page' => 1,
		'ignore_sticky_posts' => '1'
	);
 
	$lastupdated_loop = new WP_Query( $lastupdated_args );
	
	while( $lastupdated_loop->have_posts() )  {
		$lastupdated_loop->the_post();
		echo get_the_modified_date( 'M j, Y g:i a' );
	}	
	wp_reset_postdata();
}

/*
* for most use of the get_term cached 
* This is because all time it hits and single page provide data quickly
*/
function get_img( $img ){
	$img = get_stylesheet_directory_uri() . '/assets/img/' . $img;
	return $img;
}
function get_css( $file ){
	$file = get_stylesheet_directory_uri() . '/assets/css/' . $file . '.css';
	return $file;
}
function get_js( $file ){
	$file = get_stylesheet_directory_uri() . '/assets/js/' . $file . '.js';
	return $file;
}
function filter_content( $content ){
	// wp filters
	$content = wptexturize( $content );
	$content = convert_smilies( $content );
	$content = convert_chars( $content );
	$content = wpautop( $content );
	$content = shortcode_unautop( $content );

	// remove shortcodes
	$pattern= '/\[(.+?)\]/';
	$content = preg_replace( $pattern,'',$content );

	// remove tags
	$content = strip_tags( $content );

	return $content;
}

function get_current_post_content( $post = false ) {
	if ( !$post ) {
		$post = get_post();				
	}
	$content = has_excerpt( $post->ID ) ? $post->post_excerpt : $post->post_content;
	$content = filter_content( $content );
	return $content;
}

function cached_get_term_by( $field, $value, $taxonomy, $output = OBJECT, $filter = 'raw' ){
	// ID lookups are cached
	if ( 'id' == $field )
		return get_term_by( $field, $value, $taxonomy, $output, $filter );

	$cache_key = $field . '|' . $taxonomy . '|' . md5( $value );
	$term_id = wp_cache_get( $cache_key, 'get_term_by' );

	if ( false === $term_id ){
		$term = get_term_by( $field, $value, $taxonomy );
		if ( $term && ! is_wp_error( $term ) )
			wp_cache_set( $cache_key, $term->term_id, 'get_term_by' );
		else
			wp_cache_set( $cache_key, 0, 'get_term_by' ); // if we get an invalid value, let's cache it anyway
	} else {
		$term = get_term( $term_id, $taxonomy, $output, $filter );
	}

	if ( is_wp_error( $term ) )
		$term = false;

	return $term;
}

/*for avobe reason*/
function cached_get_term_link( $term, $taxonomy = null ){
	// ID- or object-based lookups already result in cached lookups, so we can ignore those.
	if ( is_numeric( $term ) || is_object( $term ) ){
		return get_term_link( $term, $taxonomy );
	}

	$term_object = cached_get_term_by( 'slug', $term, $taxonomy );
	return get_term_link( $term_object );
}


/*only to show the first category in the post - primary category*/
function ranna_if_term_exists( $term, $taxonomy = '', $parent = null ){
	if ( null !== $parent ){
		return term_exists( $term, $taxonomy, $parent );
	}

	if ( ! empty( $taxonomy ) ){
		$cache_key = $term . '|' . $taxonomy;
	}else{
		$cache_key = $term;
	}

	$cache_value = wp_cache_get( $cache_key, 'term_exists' );

	//term_exists frequently returns null, but (happily) never false
	if ( false  === $cache_value ){
		$term_exists = term_exists( $term, $taxonomy );
		wp_cache_set( $cache_key, $term_exists, 'term_exists' );
	}else{
		$term_exists = $cache_value;
	}

	if ( is_wp_error( $term_exists ) )
		$term_exists = null;

	return $term_exists;
}

if( ! function_exists( 'ranna_get_primary_category' )){

	function ranna_get_primary_category() {

		if( get_post_type() != 'post' ) {
			return;
		}

		# Get the first assigned category ----------
			$get_the_category = get_the_category();
			$primary_category = array( $get_the_category[0] );

		if( ! empty( $primary_category[0] )) {
			return $primary_category;
		}
	}
}

/*only to show the first category in the post - primary category ID*/
if( ! function_exists( 'ranna_get_primary_category_id' )){

	function ranna_get_primary_category_id(){

		$primary_category = ranna_get_primary_category();

		if( ! empty( $primary_category[0]->term_id )){
			return $primary_category[0]->term_id;
		}

		return false;
	}
}

/*for custom post term*/
if( ! function_exists( 'ranna_get_primary_term' )){

	function ranna_get_primary_term() {

		if( get_post_type() != 'post' ) {
			return;
		}
		# Get the first assigned category ----------
		
			$get_the_category = get_the_terms( get_the_ID(), 'ranna_recipe_category' );
			$primary_category = array( $get_the_category[0] );

		if( ! empty( $primary_category[0] )) {
			return $primary_category;
		}
	}
}

/*only to show the first category in the post - primary category ID*/
if( ! function_exists( 'ranna_get_primary_term_id' )){

	function ranna_get_primary_term_id(){

		$primary_category = ranna_get_primary_term();

		if( ! empty( $primary_category[0]->term_id )){
			return $primary_category[0]->term_id;
		}

		return false;
	}
}


function ranna_save_termmeta( $term_id ) {
    // Save term color if possible
    if( isset( $_POST['rt_category_color'] ) && ! empty( $_POST['rt_category_color'] ) ) {
        update_term_meta( $term_id, 'rt_category_color', sanitize_hex_color_no_hash( $_POST['rt_category_color'] ) );
    } else {
        delete_term_meta( $term_id, 'rt_category_color' );
    }
}
add_action( 'created_category', 'ranna_save_termmeta' );
add_action( 'edited_category',  'ranna_save_termmeta' );

function ranna_category_colorpicker_enqueue( $taxonomy ) {
    if( null !== ( $screen = get_current_screen() ) && 'edit-category' !== $screen->id ) {
        return;
    }
    // Colorpicker Scripts
    wp_enqueue_script( 'wp-color-picker' );
    // Colorpicker Styles
    wp_enqueue_style( 'wp-color-picker' );

}
add_action( 'admin_enqueue_scripts', 'ranna_category_colorpicker_enqueue' );

//Category Color column
add_filter( 'manage_edit-category_columns', 'ranna_edit_term_columns', 10, 3 );
function ranna_edit_term_columns( $columns ) {
    $columns['rt_category_color'] = esc_html__( 'Category Color', 'ranna' );
    return $columns;
}
// RENDER COLUMNS
add_filter( 'manage_category_custom_column', 'ranna_manage_term_custom_column', 10, 3 );
function ranna_manage_term_custom_column( $out, $column, $term_id ) {
    if ( 'rt_category_color' === $column ) {
        $value  = get_term_meta( $term_id , 'rt_category_color', true );
        if ( ! $value )
            $value = '';
        $out = sprintf( '<span class="term-meta-color-block" style="background:#%s" ></span>', esc_attr( $value ) );
    }
    return $out;
}
//find the post type function 
if ( ! function_exists ( 'ranna_post_type' ) ) {
	function ranna_post_type() {
		$ranna_post_type_var =get_post_type( get_the_ID());
		echo esc_html( $ranna_post_type_var );
	}
}

/*next previous post links*/
if ( !function_exists( 'ranna_post_links_next_prev' ) ) {
	function ranna_post_links_next_prev() { ?>
	<div class="row no-gutters divider post-navigation">
	
		<?php if ( !empty( get_next_post_link())){ ?>
			<div class=" col-lg-6 col-md-6 col-sm-6 col-6 d-flex <?php if ( empty( get_previous_post_link())){ ?>-offset-md-6<?php } ?> <?php if ( is_rtl() ){ echo esc_attr( 'text-left' ); } else { echo esc_attr( 'text-left' ); } ?>">
				<?php $next_post = get_next_post();
				if (!empty( $next_post )) { ?>
				<?php if (has_post_thumbnail( $next_post->ID )) { ?>
				<a class="left-img" href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>"><?php echo get_the_post_thumbnail( $next_post->ID, 'thumbnail', array( 'class' => 'Next' ) ); ?></a><?php } ?>
				<?php } ?>
				<div class="pad-lr-15">
				<span class="next-article">
				<?php next_post_link( '%link', esc_html('Previous article' , 'ranna' ) );?></span>
				<?php next_post_link( '<h3 class="post-nav-title">%link</h3>' ); ?>
				</div>
			
			</div>
		<?php } ?>

		<?php if ( !empty( get_previous_post_link())){ ?>
			<div class="col-lg-6 col-md-6 col-sm-6 col-6 d-flex <?php if ( empty( get_next_post_link())){ ?>offset-md-6<?php } ?> <?php if ( is_rtl() ){ echo esc_attr( 'text-right' ); } else { echo esc_attr( 'text-right' ); } ?>">

				<div class="pad-lr-15">
				<span class="prev-article">
				<?php previous_post_link( '%link', esc_html('Next article' , 'ranna' ) );?></span>
				<?php previous_post_link('<h3 class="post-nav-title">%link</h3>'); ?>
				</div>
				<?php $previous_post = get_previous_post();
				if (!empty( $previous_post )) { ?>
				<?php if ( has_post_thumbnail( $previous_post->ID ) ) { ?>
				<a class="right-img" href="<?php echo esc_url( get_permalink( $previous_post->ID ) ); ?>"><?php echo get_the_post_thumbnail( $previous_post->ID, 'thumbnail', array( 'class' => 'Previous' ) ); ?></a><?php } ?>
				<?php } ?>

			</div>
		<?php } ?>
	</div>
<?php }
}

/*next previous post links*/
if ( !function_exists( 'ranna_post_links_next_prev_recipe' ) ) {
	function ranna_post_links_next_prev_recipe() { ?>
	<!--new set -->
	<div class="next-prev-post">
	
		<div class="prev-post">
			<?php
				$previous_post = get_previous_post();			
				if (!empty( $previous_post )) { ?>
				  <a href="<?php echo esc_url( get_permalink( $previous_post->ID ) ); ?>"><?php echo get_the_post_thumbnail( $previous_post, 'thumbnail', array( 'class' => 'Previous' ) ); ?></a>
			<?php } ?>			
			<div class="item-content">
				<p><?php previous_post_link('%link', esc_html('Previous Post' , 'ranna' )); ?></p>
				<?php previous_post_link('<h3 class="post-title">%link</h3>'); ?>
			</div>			
		</div>
		
		<div class="next-post">
			<div class="item-content">
				<p><?php next_post_link( '%link', esc_html('Next Post' , 'ranna' )); ?></p>				
				<?php next_post_link( '<h3 class="post-title">%link</h3>' ); ?>
			</div>
			<?php
				$next_post = get_next_post();
				if (!empty( $next_post )) { ?>
				  <a href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>"><?php echo get_the_post_thumbnail( $next_post->ID, 'thumbnail', array( 'class' => 'Next' ) ); ?></a>
			<?php } ?>			
		</div>
		
	</div>
	
<?php }
}
/*Remove the archive label*/
function ranna_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
        $title = single_tag_title( '', false );
    } elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    } elseif ( is_tax() ) {
        $title = single_term_title( '', false );
    }
  
    return $title;
}
 
add_filter( 'get_the_archive_title', 'ranna_archive_title' );

/*Infinity scroll - Ajax */
function ranna_infinity_loading_ajax_handler(){
	
	$paged = isset($_POST['paged']) ? (absint($_POST['paged']) + 1) : 1;
	
	$num = RannaTheme::$options['infinity_post_load_number'];
	
	$initial_post_num = get_option( 'posts_per_page' );
	
	$args = array(
		'paged' => $paged,
		'offset' => $initial_post_num + ( $paged * $num ) ,
		'posts_per_page' => $num
	);
	$html = null;
	$more = true;
	$layout = $_POST['layout'];
	query_posts( $args );
 
	if( have_posts() ) {
		ob_start();
		// run the loop
		while( have_posts() ): the_post(); 
			
			if ( RannaTheme::$options['blog_style'] == 'style5' ) {
				get_template_part( 'template-parts/content-5-masonry', get_post_format() );
			} else if ( RannaTheme::$options['blog_style'] == 'style4' ) {
				get_template_part( 'template-parts/content-4-masonry', get_post_format() );
			} else if ( RannaTheme::$options['blog_style'] == 'style3' ) {
				get_template_part( 'template-parts/content-3', get_post_format() );
			} else if ( RannaTheme::$options['blog_style'] == 'style2' ) {
				if ( $layout == 'right-sidebar' || $layout == 'left-sidebar' ) {
				get_template_part( 'template-parts/content-2-sidebar', get_post_format() );				
				} else {
				get_template_part( 'template-parts/content-2-nosidebar', get_post_format() );
				}
				
			} else if ( RannaTheme::$options['blog_style'] == 'style1' ) {
				get_template_part( 'template-parts/content-1', get_post_format() );
			} 
 
		endwhile;
		$html = ob_get_clean();
 
	} else {
		$more = false;
	}	
	wp_send_json(compact('paged', 'html', 'more'));	
}

add_action('wp_ajax_ranna_infinity_loadmore', 'ranna_infinity_loading_ajax_handler'); // wp_ajax_{action}
add_action('wp_ajax_nopriv_ranna_infinity_loadmore', 'ranna_infinity_loading_ajax_handler'); // wp_ajax_nopriv_{action}

/*account update form Ajax*/
function rt_accountupdate() {

	$error = true;
	$msg = null;
	$user_id = get_current_user_id();
	
	//$ufirstname = isset( sanitize_text_field( $_POST['ufirstname'] ) );
    
	$all_data = array( 'ID' => $user_id );
	
	if( isset( $_POST['ufirstname'] ) && $ufirstname =  sanitize_text_field( $_POST['ufirstname'] )){
		$all_data['first_name']= $ufirstname;
	}	
	if( isset( $_POST['ulastname'] ) && $ulastname =  sanitize_text_field( $_POST['ulastname'] )){
		$all_data['last_name']= $ulastname;
	}	
	if( isset( $_POST['udescription'] ) && $udescription =  sanitize_text_field( $_POST['udescription'] )){
		$all_data['description']= $udescription;
	}	
	if( isset( $_POST['uwebsite'] ) && $uwebsite =  sanitize_text_field( $_POST['uwebsite'] )){
		$all_data['user_url']= $uwebsite;
	}	
	if( isset( $_POST['udesignation'] ) && $udesignation =  sanitize_text_field( $_POST['udesignation'] )){
		$all_data['ranna_author_designation']= $udesignation;
	}	
	if( isset( $_POST['ucompany'] ) && $ucompany =  sanitize_text_field( $_POST['ucompany'] )){
		$all_data['ranna_author_company']= $ucompany;
	}	
	if( isset( $_POST['ufacebook'] ) && $ufacebook =  sanitize_text_field( $_POST['ufacebook'] )){
		$all_data['ranna_facebook']= $ufacebook;
	}	
	if( isset( $_POST['utwitter'] ) && $utwitter =  sanitize_text_field( $_POST['utwitter'] )){
		$all_data['ranna_twitter']= $utwitter;
	}	
	if( isset( $_POST['ulinked'] ) && $ulinked =  sanitize_text_field( $_POST['ulinked'] )){
		$all_data['ranna_linkedin']= $ulinked;
	}	
	if( isset( $_POST['ugplus'] ) && $ugplus =  sanitize_text_field( $_POST['ugplus'] )){
		$all_data['ranna_gplus']= $ugplus;
	}	
	if( isset( $_POST['upinterest'] ) && $upinterest =  sanitize_text_field( $_POST['upinterest'] )){
		$all_data['ranna_pinterest']= $upinterest;
	}	
	if( isset( $_POST['uaddress'] ) && $uaddress =  sanitize_text_field( $_POST['uaddress'] )){
		$all_data['ranna_address']= $uaddress;
	}	
	if( isset( $_POST['ucity'] ) && $ucity =  sanitize_text_field( $_POST['ucity'] )){
		$all_data['ranna_author_city']= $ucity;
	}	
	if( isset( $_POST['ustate'] ) && $ustate =  sanitize_text_field( $_POST['ustate'] )){
		$all_data['ranna_author_state']= $ustate;
	}
	if( isset( $_POST['ucountry'] ) && $ucountry =  sanitize_text_field( $_POST['ucountry'] )){
		$all_data['ranna_author_country']= $ucountry;
	}
	if( isset( $_POST['uzipcode'] ) && $uzipcode =  sanitize_text_field( $_POST['uzipcode'] )){
		$all_data['ranna_author_zipcode']= $uzipcode;
	}
	
	$user_id = wp_update_user( $all_data );

	if ( is_wp_error( $user_id ) ) {		
		$msg = 'There is an error on updating the Information';
	} else {
		$error = false;
		$msg = 'Successfully updated';
	}	
   
	wp_send_json(array( 'error' => $error, 'msg' => $msg, 'data' => $user_id ));	
}

add_action('wp_ajax_rt_accountupdate', 'rt_accountupdate');
add_action('wp_ajax_nopriv_rt_accountupdate', 'rt_accountupdate');


/*Like action */
function rn_ranna_like_action(){	
	
	$authorID = esc_html( $_POST['authorID'] );
	$recipeID = esc_html( $_POST['recipeID'] );
	
	if ( is_user_logged_in() ) {
		
		$current_user = wp_get_current_user();
		$liked_posts = get_user_meta( $current_user->ID, 'liked_recipe', true );
		
		$success= false;
		$massage = null;
		
		if ( in_array( $recipeID,  $liked_posts ) ) {	
			// duplicate clicked found
			$success= false;
			$massage = esc_html( 'You have already liked it', 'ranna' );
		} else {			
			// Like option
			$previous_like = get_post_meta( $recipeID , 'rt_like_num', true );
			$new_like = $previous_like + 1;
			update_post_meta( $recipeID, 'rt_like_num' , $new_like );
			
			// Author option
			$like_list = get_user_meta( $authorID, 'liked_recipe', true );

			if( empty( $like_list ) ) {
				update_user_meta( $authorID, 'liked_recipe', array( $recipeID ) );
			} else {
				$author_arr = ( is_array( $like_list ) ) ? $like_list : array();
				
				$author_arr[] = $recipeID;
				update_user_meta( $authorID, 'liked_recipe', $author_arr );
			}
			
			$success= true;
			$massage = esc_html( 'liked', 'ranna' );
			$final_count_update = get_post_meta( $recipeID, 'rt_like_num' , true );
			
		}
	} else {
		// user not logged in
		$success= false;
		$massage = esc_html( 'User is not logged in', 'ranna' );
	}
	
	wp_send_json(array('success' => $success , 'msg' => $massage , 'finalcount' => $final_count_update ));
}

add_action('wp_ajax_ranna_like_action', 'rn_ranna_like_action');
add_action('wp_ajax_nopriv_ranna_like_action', 'rn_ranna_like_action'); 


add_filter('loop_shop_columns', 'ranna_loop_columns', 999);

function ranna_loop_columns() {
	$shop_product_column = RannaTheme::$options['wc_num_product_shop_page'];
	return $shop_product_column;
}

/*Find like number of the post*/
function rt_like_count( $pid ){
	$like = get_post_meta( $pid, 'rt_like_num', true );
	if ( !empty( $like ) ){
		echo esc_html( $like );
	} else {
		echo '0';
	}
}

/*Allow HTML for the kses post*/
function ranna_kses_allowed_text_html() {
	return array (
		'a' => array(
			'class' => array(),
			'href'  => array(),
			'rel'   => array(),
			'title' => array(),
		),
		'abbr' => array(
			'title' => array(),
		),
		'b' => array(),
		'blockquote' => array(
			'cite'  => array(),
		),
		'cite' => array(
			'title' => array(),
		),
		'code' => array(),
		'del' => array(
			'datetime' => array(),
			'title' => array(),
		),
		'dd' => array(),
		'div' => array(
			'class' => array(),
			'title' => array(),
			'style' => array(),
			'id' 	=> array(),
		),
		'dl' => array(),
		'dt' => array(),
		'em' => array(),
		'h1' => array(),
		'h2' => array(),
		'h3' => array(),
		'h4' => array(),
		'h5' => array(),
		'h6' => array(),
		'i' => array(),
		'img' => array(
			'alt'    => array(),
			'class'  => array(),
			'height' => array(),
			'src'    => array(),
			'srcset' => array(),
			'width'  => array(),
		),
		'li' => array(
			'class' => array(),
		),
		'ol' => array(
			'class' => array(),
		),
		'p' => array(
			'class' => array(),
		),
		'q' => array(
			'cite' => array(),
			'title' => array(),
		),
		'span' => array(
			'class' => array(),
			'title' => array(),
			'style' => array(),
		),
		'strike' => array(),
		'strong' => array(),
		'ul' => array(
			'class' => array(),
		),
	);
}

add_filter( 'wp_kses_allowed_html', 'ranna_kses_allowed_text_html', 10, 2 );

function ranna_elementor_widgets_wordpress_widget_args_cb($widget_args){
	
	$widget_args['before_title'] = '<h3>';
	$widget_args['after_title'] = '</h3>';	
	
	return $widget_args;
}

/*Pingback */
function ranna_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'ranna_pingback_header' );

/**/
add_filter('elementor/widgets/wordpress/widget_args', 'ranna_elementor_widgets_wordpress_widget_args_cb');