<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

if( ! function_exists( 'ranna_related_recipe' )){
	
	function ranna_related_recipe(){
			
		$post_id = get_the_id();	
		$number_of_avail_post = '';
		$current_post = array( $post_id );	
		$title_length = RannaTheme::$options['show_related_recipes_title_limit'] ? RannaTheme::$options['show_related_recipes_title_limit'] : '';
		$related_post_number = RannaTheme::$options['show_related_recipe_number'];

		# Making ready to the Query ...
		$query_type = RannaTheme::$options['related_recipe_query'];

		$args = array(
			'post_type'				 => 'ranna_recipe',
			'post__not_in'           => $current_post,
			'posts_per_page'         => $related_post_number,
			'no_found_rows'          => true,
			'post_status'            => 'publish',
			'ignore_sticky_posts'    => true,
			'update_post_term_cache' => false,
		);

		# Checking Related Posts Order ----------
		if( RannaTheme::$options['related_recipe_sort'] ){

			$post_order = RannaTheme::$options['related_recipe_sort'];

			if( $post_order == 'rand' ){

				$args['orderby'] = 'rand';
			}
			elseif( $post_order == 'views' ){

				$args['orderby']  = 'meta_value_num';
				$args['meta_key'] = 'ranna_views';
			}
			elseif( $post_order == 'popular' ){

				$args['orderby'] = 'comment_count';
			}
			elseif( $post_order == 'modified' ){

				$args['orderby'] = 'modified';
				$args['order']   = 'ASC';
			}
			elseif( $post_order == 'recent' ){

				$args['orderby'] = '';
				$args['order']   = '';
			}
		}

		# Get related posts by author ----------
		if( $query_type == 'author' ){
			$args['author'] = get_the_author_meta( 'ID' );
		}

		# Get related posts by tags ----------
		elseif( $query_type == 'tag' ){
			$tags_ids  = array();
			$post_tags = get_the_terms( $post_id, 'post_tag' );

			if( ! empty( $post_tags ) ){
				foreach( $post_tags as $individual_tag ){
					$tags_ids[] = $individual_tag->term_id;
				}

				$args['tag__in'] = $tags_ids;
			}
		}

		# Get related posts by categories ----------
		else{
			$category_ids = array();
			$categories   = get_the_category( $post_id );

			foreach( $categories as $individual_category ){
				$category_ids[] = $individual_category->term_id;
			}

			$args['category__in'] = $category_ids;
		}

		# Get the posts ----------
		$related_query = new wp_query( $args );
		/*the_carousel*/
		if ( RannaTheme::$layout == 'full-width' ) {
			$responsive = array(
				'0'    => array( 'items' => 1 ),
				'480'  => array( 'items' => 2 ),
				'768'  => array( 'items' => 3 ),
				'992'  => array( 'items' => 4 ),
			);
		}
		else {
			$responsive = array(
				'0'    => array( 'items' => 1 ),
				'480'  => array( 'items' => 2 ),
				'768'  => array( 'items' => 2 ),
				'992'  => array( 'items' => 3 ),
			);
		}
		
		$count_post = $related_query->post_count;
		if ( $count_post < 4 ) {
			$number_of_avail_post = false;
		} else {
			$number_of_avail_post = true;
		}
		
		$owl_data = array( 
			'nav'                => false,
			'dots'               => false,
			'autoplay'           => true,
			'autoplayTimeout'    => '5000',
			'autoplaySpeed'      => '200',
			'autoplayHoverPause' => true,
			'loop'               => $number_of_avail_post,
			'margin'             => 10,
			'responsive'         => $responsive
		);

		$owl_data = json_encode( $owl_data );
		wp_enqueue_style( 'owl-carousel' );
		wp_enqueue_style( 'owl-theme-default' );
		wp_enqueue_script( 'owl-carousel' );		
		
		$wrapper_class = '';
		if ( !$count_post ) {
			$wrapper_class .= ' no-nav';
		}
		
		if( $related_query->have_posts() ) { ?>
		
		<div class="owl-wrap rt-woo-nav rt-related-post related post also-like-wrap <?php echo esc_attr( $wrapper_class );?>">
		
			<div class="title-section">
				<h4 class="owl-custom-nav-title also-like-title"><?php echo esc_html( RannaTheme::$options['show_related_recipe_title'] ); ?></h4>
				<?php if ( $count_post > 3 ){ ?>
				<div class="owl-custom-nav owl-nav">
					<div class="owl-prev"><i class="fa fa-angle-left"></i></div><div class="owl-next"><i class="fa fa-angle-right"></i></div>
				</div>
				<?php } ?>
				<div class="owl-custom-nav-bar"></div>
				<div class="clear"></div>
			</div>
			
			<div class="owl-theme owl-carousel rt-owl-carousel" data-carousel-options="<?php echo esc_attr( $owl_data );?>">
				<?php
					while ( $related_query->have_posts() ) {
					$related_query->the_post();
					$trimmed_title = wp_trim_words( get_the_title(), $title_length, '' );
					$cats = get_the_term_list( get_the_ID(), 'ranna_recipe_category', '<span class="ctg-name">', ', ', '</span>' );
				?>
				<div class="position-relative">
					<div class="product-box-layout2">
						<figure class="item-figure">
							<?php
								$id = get_the_ID();
								$thumbnail = false;
								if ( has_post_thumbnail() ){
									$post_thumbnail_id = get_post_thumbnail_id( $id );
									$image_attributes = wp_get_attachment_image_src( $post_thumbnail_id , 'ranna-size3'  );
									if ( $image_attributes ) : ?>
										<img src="<?php echo esc_attr( $image_attributes[0] ); ?>" width="<?php echo esc_attr( $image_attributes[1] ); ?>" height="<?php echo esc_attr( $image_attributes[2] ); ?>" alt="<?php echo the_title(); ?>" />
									<?php endif; 
								} else {
									$thumbnail = '<img class="" src="'.RANNA_IMG_URL.'noimage_260X286.jpg" alt="'. the_title_attribute(array('echo'=> false)) .'">';
									echo wp_kses ( $thumbnail, 'alltext_allow' ); 
								}
								
							?></figure>
						<div class="item-content">
							<?php if ( !empty( $cats ) ) { ?>
								<div class="sub-title tag-list"><?php echo wp_kses( $cats , 'alltext_allow' ); ?></div>
							<?php } ?>
							<h3 class="item-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
							<div><?php ranna_get_comments_rating_avg_star(); ?></div>
							<ul class="entry-meta">								
								<li><i class="fa fa-user"></i>  <?php echo esc_html( 'by', 'ranna'); ?> <span><?php the_author_posts_link();?></span></li>
							</ul>
						</div>
					</div>
				</div>
				<?php } ?>
			</div>
		</div>
		
		<?php }
		
		wp_reset_postdata();
		
	}
}
?>