<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

/*-------------------------------------
#. Theme supports for WooCommerce
---------------------------------------*/
function ranna_wc_support() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
}

/*-------------------------------------
#. Replace WooCommerce Default functions
---------------------------------------*/
// Short description - Use excerpt when description doesn't exist
if ( ! function_exists( 'woocommerce_template_single_excerpt' ) ) {
	function woocommerce_template_single_excerpt() {
		global $post;
		if ( ! $post->post_excerpt && !RannaTheme::$options['wc_show_excerpt'] ) {
			return false;
		}

		echo '<div class="short-description">';
		if ( ! $post->post_excerpt ) {
			the_excerpt();
		}
		else {
			wc_get_template( 'single-product/short-description.php' );
		}
		echo '</div>';
	}
}

/*-------------------------------------
#. Custom functions used directly
---------------------------------------*/
function ranna_wc_product_slider( $products, $title, $type='' ) {
	include RANNA_BASE_DIR . 'wc-template-parts/content-product-slider.php';
}

/*-------------------------------------
#. Custom functions used in hooks
---------------------------------------*/

function ranna_header_cart_count( $fragments ) {
	global $woocommerce;
	ob_start();?>
	<span class="cart-icon-num"><?php echo WC()->cart->get_cart_contents_count();?></span>
	<?php
	$fragments['span.cart-icon-num'] = ob_get_clean();
	return $fragments;
}

function ranna_smallscreen_breakpoint(){
	return '767px';
}

function ranna_wc_hide_page_title(){
	return false;
}

function ranna_wc_loop_shop_per_page(){
	return RannaTheme::$options['wc_num_product'];
}

function ranna_wc_wrapper_start() {
	get_template_part( 'wc-template-parts/content', 'shop-header' );
}

function ranna_wc_wrapper_end() {
	get_template_part( 'wc-template-parts/content', 'shop-footer' );
}

function ranna_wc_shop_topbar(){
	get_template_part( 'wc-template-parts/content', 'shop-top' );
}

function ranna_wc_loop_product_title(){
	echo '<h3><a href="' . get_the_permalink() . '" class="woocommerce-LoopProduct-link">' . get_the_title() . '</a></h3>';
}

function ranna_wc_loop_shop_columns(){
	if ( RannaTheme::$layout == 'full-width' ) {
		return 4;
	}
	return 3;
}

function ranna_wc_shop_thumb_area(){
	get_template_part( 'wc-template-parts/content', 'shop-thumb' );
}

function ranna_wc_shop_info_wrap_start(){
	if ( is_rtl() ) {  $align = 'text-right'; } else { $align='text-center'; } 
	echo '<div class="product-info-area '. $align .'">';
}

function ranna_wc_shop_add_description(){
	if ( is_shop() || is_product_category() || is_product_tag() ) {
		global $post;
		echo '<div class="shop-excerpt grid-hide"><div class="short-description">';
		the_excerpt();
		echo '</div></div>';	
	}
}

function ranna_wc_shop_info_wrap_end(){
	echo '</div>';
}

function ranna_wc_render_sku(){ 
	get_template_part( 'wc-template-parts/content', 'product-sku' );
}

function ranna_wc_render_meta(){
	get_template_part( 'wc-template-parts/content', 'product-meta' );
}

function ranna_wc_show_or_hide_related_products(){
	// Show or hide related products
	if ( empty( RannaTheme::$options['wc_related'] ) ) {
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	}
}

function ranna_wc_hide_product_data_tab( $tabs ){
	if ( empty( RannaTheme::$options['wc_description'] ) ) {
		unset( $tabs['description'] );
	}
	if ( empty( RannaTheme::$options['wc_reviews'] ) ) {
		unset( $tabs['reviews'] );
	}
	if ( empty( RannaTheme::$options['wc_additional_info'] ) ) {
		unset( $tabs['additional_information'] );
	}
	return $tabs;
}

function ranna_wc_product_review_form( $comment_form ){
	$commenter = wp_get_current_commenter();

	$comment_form['fields'] = array(
		'author' => '<div class="row"><div class="col-sm-6"><div class="comment-form-author form-group"><input id="author" name="author" type="text" class="form-control" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" placeholder="' . esc_attr__( 'Name *', 'ranna' ) . '" required /></div></div>',
		'email'  => '<div class="comment-form-email col-sm-6"><div class="form-group"><input id="email" class="form-control" name="email" type="email" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" placeholder="' . esc_attr__( 'Email *', 'ranna' ) . '" required /></div></div></div>',
	);

	$comment_form['comment_field'] = '';

	if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) {
		$comment_form['comment_field'] = '<p class="comment-form-rating"><label for="rating">' . esc_html__( 'Your Rating', 'ranna' ) .'</label>
		<select name="rating" id="rating" required>
			<option value="">' . esc_html__( 'Rate&hellip;', 'ranna' ) . '</option>
			<option value="5">' . esc_html__( 'Perfect', 'ranna' ) . '</option>
			<option value="4">' . esc_html__( 'Good', 'ranna' ) . '</option>
			<option value="3">' . esc_html__( 'Average', 'ranna' ) . '</option>
			<option value="2">' . esc_html__( 'Not that bad', 'ranna' ) . '</option>
			<option value="1">' . esc_html__( 'Very Poor', 'ranna' ) . '</option>
		</select></p>';
	}

	$comment_form['comment_field'] .= '<div class="col-sm-12 acurate"><div class="form-group comment-form-comment"><textarea id="comment" name="comment" class="form-control" placeholder="' . esc_attr__( 'Your Review *', 'ranna' ) . '" cols="45" rows="8" required></textarea></div></div>';

	return $comment_form;
}

function ranna_wc_show_or_hide_cross_sells(){
	// Show or hide related cross sells
	if ( !empty( RannaTheme::$options['wc_cross_sell'] ) ) {
		add_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display', 10 );
	}
}

/*whishlist button here*/
function ranna_add_wishlist_button() {
		
	global $product;
	//$product_id      = $product->get_id();
	$product_id      = get_the_ID();
	$is_in_wishlist  = YITH_WCWL()->is_product_in_wishlist( $product_id, false );
	$wishlist_url    = YITH_WCWL()->get_wishlist_url();

	$title_before = esc_html__( 'Add to Wishlist', 'ranna' );
	$title_after  = esc_html__( 'Aleady exists in Wishlist! Click here to view Wishlist', 'ranna' );

	if ( $is_in_wishlist ) {
		$class      = 'rdtheme-remove-from-wishlist';
		$icon_font  = 'fa fa-heart';
		$title      = $title_after;
	}
	else {
		$class      = 'rdtheme-add-to-wishlist';
		$icon_font  = 'fa fa-heart-o';
		$title      = $title_before;
	}

	$html = '';

	$html .= '<i class="wishlist-icon '.$icon_font.'"></i>';

	return '<a href="'. esc_url( $wishlist_url ) .' " title="'. esc_attr( $title ) .'" rel="nofollow" data-product-id="'. esc_attr( $product_id ) .'" data-title-after="'. esc_attr( $title_after ) .'" class="rdtheme-wishlist-icon '. esc_attr( $class ) . '" target="_blank">'. wp_kses( $html , 'alltext_allow' ) .'
	</a>';
}

/*Price Part - Parvez*/
if (!function_exists('ranna_commonPriceHtml')) {

    function ranna_commonPriceHtml($price_amt, $regular_price, $sale_price) {
        $html_price = '<p class="price">';
        //if product is in sale
        if (($price_amt == $sale_price) && ($sale_price != 0)) {
            $html_price .= '<ins>' . wc_price($sale_price) . '</ins>';
            $html_price .= '<del>' . wc_price($regular_price) . '</del>';
        }
        //in sale but free
        else if (($price_amt == $sale_price) && ($sale_price == 0)) {
            $html_price .= '<ins>Free!</ins>';
            $html_price .= '<del>' . wc_price($regular_price) . '</del>';
        }
        //not is sale
        else if (($price_amt == $regular_price) && ($regular_price != 0)) {
            $html_price .= '<ins>' . wc_price($regular_price) . '</ins>';
        }
        //for free product
        else if (($price_amt == $regular_price) && ($regular_price == 0)) {
            $html_price .= '<ins>Free!</ins>';
        }
        $html_price .= '</p>';
        return $html_price;
    }

}

add_filter('woocommerce_get_price_html', 'ranna_simple_product_price_html', 100, 2);

function ranna_simple_product_price_html($price, $product) {
    if ($product->is_type('simple')) {
        $regular_price = $product->get_regular_price();
        $sale_price = $product->get_sale_price();
        $price_amt = $product->get_price();
        return ranna_commonPriceHtml($price_amt, $regular_price, $sale_price);
    } else {
        return $price;
    }
}

add_filter('woocommerce_variation_sale_price_html', 'ranna_variable_product_price_html', 10, 2);
add_filter('woocommerce_variation_price_html', 'ranna_variable_product_price_html', 10, 2);

function ranna_variable_product_price_html($price, $variation) {
    $variation_id = $variation->variation_id;
    //creating the product object
    $variable_product = new WC_Product($variation_id);

    $regular_price = $variable_product->get_regular_price();
    $sale_price = $variable_product->get_sale_price();
    $price_amt = $variable_product->get_price();

    return ranna_commonPriceHtml($price_amt, $regular_price, $sale_price);
}

add_filter('woocommerce_variable_sale_price_html', 'ranna_variable_product_minmax_price_html', 10, 2);
add_filter('woocommerce_variable_price_html', 'ranna_variable_product_minmax_price_html', 10, 2);

function ranna_variable_product_minmax_price_html($price, $product) {
    $variation_min_price = $product->get_variation_price('min', true);
    $variation_max_price = $product->get_variation_price('max', true);
    $variation_min_regular_price = $product->get_variation_regular_price('min', true);
    $variation_max_regular_price = $product->get_variation_regular_price('max', true);

    if (($variation_min_price == $variation_min_regular_price) && ($variation_max_price == $variation_max_regular_price)) {
        $html_min_max_price = $price;
    } else {
        $html_price = '<p class="pric">';
        $html_price .= '<ins>' . wc_price($variation_min_price) . '-' . wc_price($variation_max_price) . '</ins>';
        $html_price .= '<del>' . wc_price($variation_min_regular_price) . '-' . wc_price($variation_max_regular_price) . '</del>';
        $html_min_max_price = $html_price;
    }

    return $html_min_max_price;
}